import * as _versini_ui_private_dist_utilities from '@versini/ui-private/dist/utilities';
import { SpacingProps } from '@versini/ui-private/dist/utilities';
import * as React$1 from 'react';
import React__default from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';
import { Placement } from '@floating-ui/react';

declare const Anchor: React__default.ForwardRefExoticComponent<{
    children?: React__default.ReactNode;
    link?: string | undefined;
    maxLabelLength?: number | undefined;
    noTruncate?: boolean | undefined;
} & {
    children: React__default.ReactNode;
    disabled?: boolean | undefined;
    onClick?: React__default.MouseEventHandler<HTMLButtonElement> | undefined;
} & {
    className?: string | undefined;
    focusMode?: "dark" | "light" | "system" | "alt-system" | undefined;
    fullWidth?: boolean | undefined;
    mode?: "dark" | "light" | "system" | "alt-system" | undefined;
    noBorder?: boolean | undefined;
    raw?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
} & _versini_ui_private_dist_utilities.SpacingProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.AnchorHTMLAttributes<HTMLAnchorElement> & React__default.RefAttributes<HTMLAnchorElement>>;

type BubbleProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * Whether or not to show a "copy/paste" icon next to the Bubble.
	 */
	copyToClipboard?: boolean | string | ((text: any) => void);
	/**
	 * Object depicting the extra rows for the Bubble.
	 * @example
	 * ```tsx
	 * <Bubble
	 * 	footer={{
	 * 		"Sent": "12:00 PM",
	 * 		"Delivered": "12:01 PM",
	 * 		"Read": "12:02 PM",
	 * 	}}
	 * >Hello World</Bubble>
	 * ```
	 */
	footer?: {
		[key: string]: string | number | undefined | null;
	};
	/**
	 * The type of Bubble. This will change the color of the Bubble
	 * as well as the chevron location.
	 */
	kind?: "left" | "right";
	/**
	 * Same as "footer" but accepts raw JSX.
	 */
	rawFooter?: React.ReactNode;
} & SpacingProps;

declare const Bubble: ({ children, kind, className, footer, rawFooter, copyToClipboard, spacing, }: BubbleProps) => react_jsx_runtime.JSX.Element;

declare const Button: React__default.ForwardRefExoticComponent<{
    children: React__default.ReactNode;
    disabled?: boolean | undefined;
    onClick?: React__default.MouseEventHandler<HTMLButtonElement> | undefined;
} & {
    className?: string | undefined;
    focusMode?: "dark" | "light" | "system" | "alt-system" | undefined;
    fullWidth?: boolean | undefined;
    mode?: "dark" | "light" | "system" | "alt-system" | undefined;
    noBorder?: boolean | undefined;
    raw?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
} & _versini_ui_private_dist_utilities.SpacingProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.RefAttributes<HTMLButtonElement>>;

declare const ButtonIcon: React__default.ForwardRefExoticComponent<{
    children: React__default.ReactNode;
    label?: string | undefined;
    labelLeft?: string | undefined;
    labelRight?: string | undefined;
    noBackground?: boolean | undefined;
} & {
    className?: string | undefined;
    focusMode?: "dark" | "light" | "system" | "alt-system" | undefined;
    fullWidth?: boolean | undefined;
    mode?: "dark" | "light" | "system" | "alt-system" | undefined;
    noBorder?: boolean | undefined;
    raw?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
} & _versini_ui_private_dist_utilities.SpacingProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.RefAttributes<HTMLButtonElement>>;

declare const ButtonLink: React__default.ForwardRefExoticComponent<{
    children?: React__default.ReactNode;
    link?: string | undefined;
    maxLabelLength?: number | undefined;
    noTruncate?: boolean | undefined;
} & {
    children: React__default.ReactNode;
    disabled?: boolean | undefined;
    onClick?: React__default.MouseEventHandler<HTMLButtonElement> | undefined;
} & {
    className?: string | undefined;
    focusMode?: "dark" | "light" | "system" | "alt-system" | undefined;
    fullWidth?: boolean | undefined;
    mode?: "dark" | "light" | "system" | "alt-system" | undefined;
    noBorder?: boolean | undefined;
    raw?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
} & _versini_ui_private_dist_utilities.SpacingProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.AnchorHTMLAttributes<HTMLAnchorElement> & React__default.RefAttributes<HTMLAnchorElement>>;

type CardProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;

	/**
	 * If the header prop is not provided, the Card must be
	 * described via aria-labelledby.
	 */
	"aria-labelledby"?: string;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * The content to render in the footer.
	 */
	footer?: React.ReactNode;
	/**
	 * CSS class(es) to add to the footer.
	 */
	footerClassName?: string;
	/**
	 * The content to render in the header.
	 */
	header?: React.ReactNode;
	/**
	 * CSS class(es) to add to the header.
	 */
	headerClassName?: string;
	/**
	 * The mode of Card. This will change the color of the Card.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
} & SpacingProps;

declare const Card: ({ header, headerClassName, footer, footerClassName, children, className, "aria-labelledby": ariaLabelledby, spacing, mode, ...otherProps }: CardProps) => react_jsx_runtime.JSX.Element;

type FooterProps = {
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * The type of Footer. This will change the color of the Footer.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * Whether or not to render the Footer with margins.
	 * @default false
	 */
	noMargins?: boolean;
	/**
	 * Whether or not to render the Footer component with no styles.
	 * @default false
	 */
	raw?: boolean;
	/**
	 * The content to render in the first row.
	 */
	row1?: React.ReactNode;
	/**
	 * The content to render in the second row.
	 */
	row2?: React.ReactNode;
} & SpacingProps;

declare const Footer: ({ className, mode, row1, row2, noMargins, spacing, raw, }: FooterProps) => react_jsx_runtime.JSX.Element;

type HeaderProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * Whether or not to render the Header component with no styles.
	 * @default false
	 */
	raw?: boolean;
} & SpacingProps;

declare const Header: ({ children, className, raw, spacing, }: HeaderProps) => react_jsx_runtime.JSX.Element;

type MainProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * Whether or not to render the Main component with no styles.
	 * @default false
	 */
	raw?: boolean;
} & SpacingProps;

declare const Main: ({ children, className, raw, spacing, }: MainProps) => react_jsx_runtime.JSX.Element;

interface MenuProps extends SpacingProps {
	/**
	 * The children to render.
	 */
	children?: React.ReactNode;
	/**
	 * The default location of the popup.
	 * @default "bottom-start"
	 */
	defaultPlacement?: Placement;
	/**
	 * A React component of type Icon to be placed on the left of the label.
	 */
	icon?: React.ReactNode;
	/**
	 * The type of Button trigger. This will change the color of the Button.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * The label to use for the menu button.
	 */
	label?: string;
	/**
	 * Callback fired when the component is opened or closed.
	 * @param open whether or not the menu is open
	 */
	onOpenChange?: (open: boolean) => void;
}

interface MenuItemProps {
	/**
	 * The label to use for the menu item.
	 */
	label: string;
	/**
	 * Whether or not the menu item is disabled.
	 * @default false
	 */
	disabled?: boolean;
	/**
	 * A React component of type Icon to be placed on the left of the label.
	 */
	icon?: React.ReactNode;
}

type MenuSeparatorProps = React.HTMLAttributes<HTMLDivElement>;

declare const Menu: React$1.ForwardRefExoticComponent<Omit<MenuProps & React$1.HTMLProps<HTMLButtonElement>, "ref"> & React$1.RefAttributes<HTMLButtonElement>>;

declare const MenuItem: React$1.ForwardRefExoticComponent<MenuItemProps & React$1.ButtonHTMLAttributes<HTMLButtonElement> & React$1.RefAttributes<HTMLButtonElement>>;
declare const MenuSeparator: ({ className, ...props }: MenuSeparatorProps) => react_jsx_runtime.JSX.Element;

type PanelProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * Callback fired when the component is opened or closed.
	 * @param open whether or not the menu is open
	 */
	onOpenChange: (open: boolean) => void;
	/**
	 * Whether or not to open the component..
	 * @default false
	 */
	open: boolean;
	/**
	 * The title to use for the panel.
	 */
	title: string;
	/**
	 * The type of Panel border.
	 */
	borderMode?: "dark" | "light";
	/**
	 * The content to render in the footer.
	 */
	footer?: React.ReactNode;
	/**
	 * The type of Panel. This will change the layout of the Panel.
	 */
	kind?: "panel" | "messagebox";
};

declare const Panel: ({ open, onOpenChange, title, children, footer, borderMode, kind, }: PanelProps) => react_jsx_runtime.JSX.Element;

type PillProps = {
	/**
	 * Content of the Pill.
	 */
	label: string;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * Hidden label adjacent to the pill text to provide added
	 * context for screen reader users, ideally no more
	 * than 2-3 words.
	 */
	description?: string;
	/**
	 * Theme of the Pill.
	 * @default "information"
	 */
	variant?: "information" | "warning" | "error" | "success";
} & SpacingProps;

declare const Pill: ({ label, className, variant, description, spacing, }: PillProps) => react_jsx_runtime.JSX.Element;

type SpinnerProps = {
	/**
	 * The mode of spinner to render. This will change the color of the spinner.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * A ref to the spinner element.
	 */
	spinnerRef?: React.RefObject<HTMLDivElement>;
	/**
	 * The type of spinner to render. This will change the layout of the spinner.
	 */
	type?: "circle" | "dots";
} & SpacingProps;

declare const Spinner: ({ spinnerRef, mode, type, spacing, }: SpinnerProps) => react_jsx_runtime.JSX.Element;

type TableProps = {
	/**
	 * This attribute defines the caption (or title) of a table.
	 */
	caption?: React__default.ReactNode;
	/**
	 * The max height of the table. It follows the CSS max-height property.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	maxHeight?: string;
	/**
	 * The mode of table. It defines the color of the table.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * If true, the table header will be sticky.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	stickyHeader?: boolean;
	/**
	 * This attribute defines an alternative text that summarizes
	 * the content of the table. It is not visible but will be
	 * read out loud by screen readers to represent the table.
	 */
	summary?: string;
	/**
	 * CSS class to apply to the table wrapper.
	 */
	wrapperClassName?: string;
} & SpacingProps &
	React__default.HTMLAttributes<HTMLTableElement>;

type TableRowProps = React__default.HTMLAttributes<HTMLTableRowElement>;
type TableBodyProps = React__default.HTMLAttributes<HTMLTableSectionElement>;
type TableHeadProps = React__default.HTMLAttributes<HTMLTableSectionElement>;

type TableCellProps = {
	/**
	 * The type of cell.
	 * @default "td"
	 */
	component?: "td" | "th";
} & React__default.ThHTMLAttributes<HTMLTableCellElement> &
	React__default.TdHTMLAttributes<HTMLTableCellElement>;

declare const Table: ({ children, mode, caption, summary, className, wrapperClassName, maxHeight, stickyHeader, spacing, ...otherProps }: TableProps) => react_jsx_runtime.JSX.Element;
declare const TableHead: ({ children, className, ...otherProps }: TableHeadProps) => react_jsx_runtime.JSX.Element;
declare const TableBody: ({ children, ...otherProps }: TableBodyProps) => react_jsx_runtime.JSX.Element;
declare const TableRow: ({ children, className, ...otherProps }: TableRowProps) => react_jsx_runtime.JSX.Element;
declare const TableCell: ({ children, component, className, ...otherProps }: TableCellProps) => react_jsx_runtime.JSX.Element;

export { Anchor, Bubble, Button, ButtonIcon, ButtonLink, Card, Footer, Header, Main, Menu, MenuItem, MenuSeparator, Panel, Pill, Spinner, Table, TableBody, TableCell, TableHead, TableRow };
